#define F_CPU 16000000

#include <avr/io.h>
#include <util/delay.h>
#include <util/twi.h>
#include <stdio.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <string.h>
#include <stdlib.h>

#include "nokia5110/lcd.h"
#include "mpu6050/mpu6050.h"
#include "mpu6050/mpu6050registers.h"
#include "i2chw/i2cmaster.h"

#define c    261
#define d    294
#define e    329
#define f    349
#define g    391
#define gS   415
#define a    440
#define aS   455
#define b    466
#define cH   523
#define cSH  554
#define dH   587
#define dSH  622
#define eH   659
#define fH   698
#define fSH  740
#define gH   784
#define gSH  830
#define aH   880

uint16_t surprise_notess[] = {a, a, a, f, cH, a, f, cH, a, eH, eH, eH, fH, cH, gS, f, cH, a, aH, a, a, aH, gSH, gH, fSH, fH, fSH, aS, dSH, dH, cSH, cH, b, cH, f, gS, f, a, cH, a, cH, eH, aH, a, a, aH, gSH, gH, fSH, fH, fSH, aS, dSH, dH, cSH, cH, b, cH, f, gS, f, cH, a, f, cH, a};

uint16_t durationss[] = {500, 500, 500, 350, 150, 500, 350, 150, 650, 500, 500, 500, 350, 150, 500, 350, 150, 650, 500, 300, 150, 400, 200, 200, 125, 125, 250, 250, 400, 200, 200, 125, 125, 250, 125, 500, 375, 125, 500, 375, 125, 650, 500, 300, 150, 400, 200, 200, 125, 125, 250, 250, 400, 200, 200, 125, 125, 250, 250, 500, 375, 125, 500, 375, 125, 650};


uint16_t frecventa_nota[] = {262, 294, 330, 349, 392, 440, 494, 523, 570};

uint16_t durat[] = {300, 300, 300, 250, 250, 250, 250, 150, 150, 200};

#define NOTE_C4  262
#define NOTE_D4  294
#define NOTE_E4  330
#define NOTE_F4  349
#define NOTE_G4  392
#define NOTE_A4  440
#define NOTE_B4  494
#define NOTE_C5  523
#define NOTE_D5  587
#define NOTE_E5  659
#define NOTE_F5  698
#define NOTE_G5  784
#define NOTE_A5  880
#define NOTE_B5  988

uint16_t surprise_notes[] = {       
   NOTE_E4, NOTE_G4, NOTE_A4, NOTE_A4, 
   NOTE_A4, NOTE_B4, NOTE_C5, NOTE_C5, 
   NOTE_C5, NOTE_D5, NOTE_B4, NOTE_B4,
   NOTE_A4, NOTE_G4, NOTE_A4,
   
   NOTE_E4, NOTE_G4, NOTE_A4, NOTE_A4, 
   NOTE_A4, NOTE_B4, NOTE_C5, NOTE_C5, 
   NOTE_C5, NOTE_D5, NOTE_B4, NOTE_B4,
   NOTE_A4, NOTE_G4, NOTE_A4, 
   
   NOTE_E4, NOTE_G4, NOTE_A4, NOTE_A4,
   NOTE_A4, NOTE_C5, NOTE_D5, NOTE_D5, 
   NOTE_D5, NOTE_E5, NOTE_F5, NOTE_F5,
   NOTE_E5, NOTE_D5, NOTE_E5, NOTE_A4,
   
   NOTE_A4, NOTE_B4, NOTE_C5, NOTE_C5,
   NOTE_D5, NOTE_E5, NOTE_A4, 
   NOTE_A4, NOTE_C5, NOTE_B4, NOTE_B4,
   NOTE_C5, NOTE_A4, NOTE_B4,

   NOTE_A4, NOTE_A4, 
   NOTE_A4, NOTE_B4, NOTE_C5, NOTE_C5,
   NOTE_C5, NOTE_D5, NOTE_B4, NOTE_B4,
   NOTE_A4, NOTE_G4, NOTE_A4,

   NOTE_E4, NOTE_G4, NOTE_A4, NOTE_A4,
   NOTE_A4, NOTE_B4, NOTE_C5, NOTE_C5, 
   NOTE_C5, NOTE_D5, NOTE_B4, NOTE_B4,
   NOTE_A4, NOTE_G4, NOTE_A4,
   
   NOTE_E4, NOTE_G4, NOTE_A4, NOTE_A4,
   NOTE_A4, NOTE_C5, NOTE_D5, NOTE_D5, 
   NOTE_D5, NOTE_E5, NOTE_F5, NOTE_F5,
   NOTE_E5, NOTE_D5, NOTE_E5, NOTE_A4,
   
   NOTE_A4, NOTE_B4, NOTE_C5, NOTE_C5,
   NOTE_D5, NOTE_E5, NOTE_A4, 
   NOTE_A4, NOTE_C5, NOTE_B4, NOTE_B4,
   NOTE_C5, NOTE_A4, NOTE_B4,

   NOTE_E5, NOTE_F5,
   NOTE_E5, NOTE_E5, NOTE_G5, NOTE_E5, NOTE_D5,
   NOTE_D5, NOTE_C5,
   NOTE_B4, NOTE_C5,  NOTE_B4,  NOTE_A4,

   NOTE_E5, NOTE_F5,
   NOTE_E5, NOTE_E5, NOTE_G5, NOTE_E5, NOTE_D5,
   NOTE_D5, NOTE_C5,
   NOTE_B4, NOTE_C5, NOTE_B4, NOTE_A4
};

uint16_t durations[] = {
  125, 125, 250, 125, 125, 
  125, 125, 250, 125, 125,
  125, 125, 250, 125, 125,
  125, 125, 375, 125, 
  
  125, 125, 250, 125, 125, 
  125, 125, 250, 125, 125,
  125, 125, 250, 125, 125,
  125, 125, 375, 125, 
  
  125, 125, 250, 125, 125, 
  125, 125, 250, 125, 125,
  125, 125, 250, 125, 125,
  125, 125, 125, 250, 125,

  125, 125, 250, 125, 125, 
  250, 125, 250, 125, 
  125, 125, 250, 125, 125,
  125, 125, 375, 375,

  250, 125,
  125, 125, 250, 125, 125,
  125, 125, 250, 125, 125,
  125, 125, 375, 125, 
  
  125, 125, 250, 125, 125, 
  125, 125, 250, 125, 125,
  125, 125, 250, 125, 125,
  125, 125, 375, 125, 
  
  125, 125, 250, 125, 125, 
  125, 125, 250, 125, 125,
  125, 125, 250, 125, 125,
  125, 125, 125, 250, 125,

  125, 125, 250, 125, 125, 
  250, 125, 250, 125, 
  125, 125, 250, 125, 125,
  125, 125, 375, 375,
  
  250, 125, 375, 250, 125, 375,
  125, 125, 125, 125, 125, 125, 125, 125, 375,
  250, 125, 375, 250, 125, 375,
  125, 125, 125, 125, 125, 500,

  250, 125, 375, 250, 125, 375,
  125, 125, 125, 125, 125, 125, 125, 125, 375,
  250, 125, 375, 250, 125, 375,
  125, 125, 125, 125, 125, 500
};

//size-ul total al array-ului de frecvente
uint8_t num_notes = sizeof(durations) / sizeof(durations[0]);
uint8_t num_note = sizeof(durationss) / sizeof(durationss[0]);

//buffere unde voi retine scorul jucatorului curent
char player[50];
char current_player[50];
char scor_player[50];
char str[50];

//scorul si bonusul acumulat pe parcurs
int score = 0;
int bonus = 0;

//aceste variabile le folosesc pentru afisarea corecta a recordului
int len;
int len1;
int col = 1;
int col1 = 9;

//durata si numarul notei curente
int nr_nota;
int durata;
int nr_nota1;
int durata1;
int nr_nota2;
int durata2;
static int counter;

//timer folosit pentru redarea corecta a melodiei
void timer1_init() {
#if 0
    /* timer1 este configurat cu modul Normal, top 0xFFFF si prescaler 256 */
    TCCR1B |= (1 << CS12);
#endif
    TCCR1B |= (1 << CS10);
#if 0
    TIMSK1 |= (1 << OCIE1A) | (1 << TOIE1);
#endif

#if 0
    /* 16MHz / 256 = 62500 Hz */
    ICR1 = 62500;
#endif
    ICR1 = 0xFFFF;

    TCCR1A |= (1 << COM1B1) | (1 << WGM10) | (1 << WGM11);
    TCCR1B |= (1 << WGM12) | (1 << WGM13) | (1 << CS12);
#if 0
    /* duty cycle-ul este setat initial la 25% */
    OCR1A = 0xFFFF / 4;
    /* duty cycle-ul initial pentru speaker (OC1B) este 50% */
    OCR1B = 0xFFFF / 2;
#endif

}

//melodiile redate de buzzer
void update_song() {
    durata -= 25;
    if (durata < 25) {
        OCR1A = 15625 / surprise_notes[nr_nota];
        OCR1B = OCR1A/2;
        TCNT1 = 0;
        durata = durations[nr_nota];
        nr_nota = (nr_nota+1)%64;
    }
}

void update_song1()
{
    durata1 -= 25;
    if (durata1 < 25) {
        OCR1A = 15625 / surprise_notess[nr_nota1];
        OCR1B = OCR1A/2;
        TCNT1 = 0;
        durata1 = durationss[nr_nota1];
        nr_nota1 = (nr_nota1+1)%64;
    }
}


void update_song2()
{
    durata2 -= 25;
    if (durata2 < 25) {
        OCR1A = 15625 / frecventa_nota[nr_nota2];
        OCR1B = OCR1A/2;
        TCNT1 = 0;
        durata2 = durat[nr_nota2];
        nr_nota2 = (nr_nota2+1)%64;
    }
}


//functie folosita pentru afisarea caracterului pe ecran
//in dependenta de butonul apasat
char pushButton(){
	PORTA = 0b11101111;
	
	if(!(PINA & 1))
		return 'A';
	
	if(!(PINA & 1 << 1))
		return '4';
	
	if(!(PINA & 1 << 2))
		return '7';
	
	if(!(PINA & 1 << 3))
		return '*';
	
	PORTA = 0b11011111;
	
	if(!(PINA & 1))
		return '1';
	
	if(!(PINA & 1 << 1))
		return '5';
	
	if(!(PINA & 1 << 2))
		return '8';
	
	if(!(PINA & 1 << 3))
		return '0';
	
	PORTA = 0b10111111;
	
	if(!(PINA & 1))
		return '2';
	
	if(!(PINA & 1 << 1))
		return '6';
	
	if(!(PINA & 1 << 2))
		return '9';
	
	if(!(PINA & 1 << 3))
		return '#';
	
	PORTA = 0b01111111;
	
	if(!(PINA & 1))
		return '3';
	
	if(!(PINA & 1 << 1))
		return 'B';
	
	if(!(PINA & 1 << 2))
		return 'C';
	
	if(!(PINA & 1 << 3))
		return 'D';
	
	return 0;
}

//functie folosita pentru tastarea mai multor caractere
//pe lcd
char button(){
	while (!pushButton()){
		update_song();
		_delay_ms(25);	
	}
	char k = pushButton();
	while(pushButton());
	return k;
}


//in game_init fac nivelul pentru joaca 
void game_init(){
	int i;

	for(i = 1; i < 8; i++) {
		lcd_goto_xy(i,1);
		lcd_chr(WALL);
		lcd_goto_xy(i,3);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(8,1);
	lcd_chr(WALL);
	lcd_goto_xy(9,1);
	lcd_chr(WALL);
	lcd_goto_xy(10,1);
	lcd_chr(WALL);
	
	for(i = 1; i < 5; i++) {
		lcd_goto_xy(10,i);
		lcd_chr(WALL);
	}
	
	for(i = 3; i < 6; i++) {
		lcd_goto_xy(7, i);
		lcd_chr(WALL);
	}

	lcd_goto_xy(7,5);
	lcd_chr(WALL);
	
	for(i = 7; i < 17; i++) {
		lcd_goto_xy(i,6);
		lcd_chr(WALL);
	}
	
	for(i = 10; i < 17; i++) {
		lcd_goto_xy(i, 4);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(1,2);
	lcd_chr(PLAYER);
}

void game_init2()
{
	int i;

	for(i = 1; i < 14; i++) {
		lcd_goto_xy(i,1);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(16,1);
	lcd_chr(WALL);
	
	lcd_goto_xy(13,2);
	lcd_chr(WALL);
	lcd_goto_xy(16,2);
	lcd_chr(WALL);
	
	for(i = 1; i < 4; i++) {
		lcd_goto_xy(i,3);
		lcd_chr(WALL);
	}
	
	for(i = 6; i < 11; i++) {
		lcd_goto_xy(i,3);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(13,3);
	lcd_chr(WALL);
	lcd_goto_xy(16,3);
	lcd_chr(WALL);
	
	lcd_goto_xy(3,4);
	lcd_chr(WALL);
	lcd_goto_xy(16,4);
	lcd_chr(WALL);
	
	for(i = 6; i < 9; i++) {
		lcd_goto_xy(i,4);
		lcd_chr(WALL);
	}
	
	for(i = 11; i < 17; i++) {
		lcd_goto_xy(i,5);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(3,5);
	lcd_chr(WALL);
	
	for(i = 3; i < 11; i++) {
		lcd_goto_xy(i,6);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(1,2);
	lcd_chr(PLAYER);
}

void game_init3()
{
	int i;

	for(i = 1; i < 15; i++) {
		lcd_goto_xy(i,6);
		lcd_chr(WALL);
	}
	
	for(i = 1; i < 7; i++) {
		lcd_goto_xy(i,4);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(9,4);
	lcd_chr(WALL);
	lcd_goto_xy(10,4);
	lcd_chr(WALL);
	lcd_goto_xy(14,4);
	lcd_chr(WALL);
	
	lcd_goto_xy(5,3);
	lcd_chr(WALL);
	lcd_goto_xy(13,3);
	lcd_chr(WALL);
	lcd_goto_xy(9,3);
	lcd_chr(WALL);
	
	for(i = 1; i < 6; i++) {
		lcd_goto_xy(i,2);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(5,2);
	lcd_chr(WALL);
	
	lcd_goto_xy(11,1);
	lcd_chr(WALL);
	lcd_goto_xy(2,1);
	lcd_chr(WALL);
	lcd_goto_xy(6,1);
	lcd_chr(WALL);
	lcd_goto_xy(7,1);
	lcd_chr(WALL);
	lcd_goto_xy(10,1);
	lcd_chr(WALL);
	
	lcd_goto_xy(14,2);
	lcd_chr(WALL);
	lcd_goto_xy(14,3);
	lcd_chr(WALL);
	lcd_goto_xy(14,4);
	lcd_chr(WALL);
	lcd_goto_xy(14,5);
	lcd_chr(WALL);
	
	for(i = 1; i<7; ++i){
		lcd_goto_xy(17,i);
		lcd_chr(WALL);
	}
	
	lcd_goto_xy(1,5);
	lcd_chr(PLAYER);
}

//level reprezinta insusi nivelul curent curent
// x si y folosite pentru cunoasterea pozitionarii
//caracterului oe ecran
void level3(){
	int aux_xx = 2;
	int aux_xy = 2;
	int16_t ax, ay, az, gx, gy, gz;
	int flash_led = 120;
	int y = 1;
	int x = 5;
	int aux_x, aux_y;
	int i;
	int k;
	counter = 0;
	score = 0;
	
	lcd_clear();
	game_init3();
	
	while(1){
		if (counter == 80){
			_delay_ms(200);
			PORTD &= ~(1 << PD7);
			DDRD |= (1 << PD4);
			lcd_clear();
			lcd_goto_xy(6,1);
			lcd_str("YOU LOSE!");
			sprintf(str, "%d", score);
			lcd_goto_xy(5,2);
			lcd_str("YOUR FINAL");
			lcd_goto_xy(5,3);
			lcd_str("SCORE IS: ");
			lcd_goto_xy(8,4);
			lcd_str(str);
			lcd_goto_xy(5, 5);
			lcd_str("ID PLAYER: ");
			lcd_goto_xy(8, 6);
			lcd_str(player);
			
			for(i = 0; i<1000; ++i){
				update_song2();
				_delay_ms(25);
			}
			
			strcpy(str, "");
			lcd_clear();
			lcd_goto_xy(1,1);
			lcd_str("ID");
			lcd_goto_xy(9,1);
			lcd_str("SCORE");
			sprintf(str, "%d", score);
			strcat(scor_player, str);
			strcat(current_player, player);
			
			len = strlen(current_player);
			len1 = strlen(scor_player);
			
			DDRD &= ~(1 << PD4);
			col = 1;
			col1 = 9;
			for(i = 1; i < len; ++i){
				if(col == 6){
					col = 1;
					aux_xx+=1;
				}
					
				lcd_goto_xy(col,aux_xx);
				lcd_chr(current_player[i]);
					
				col+=1;
			}
				
			for(k = 1; k < len1; ++k){
				if(col1 == 13){
					col1 = 9;
					aux_xy+=1;
				}
				lcd_goto_xy(col1,aux_xy);
				lcd_chr(scor_player[k]);
					
				col1+=1;
			}
			
			_delay_ms(100000);
			
			DDRD |= (1 << PD4);
			
			lcd_clear();
			lcd_goto_xy(7,2);
			lcd_str("TO START ");
			lcd_goto_xy(4,3);
			lcd_str("A NEW GAME");
			lcd_goto_xy(6,4);
			lcd_str("PRESS #");
			strcpy(player, "");	
			char k = button();
			if (k == '#'){
				DDRD &= ~(1 << PD4);
				while(1){
					id_player();
					_delay_ms(25);
					break;
				}
			}		
			
			break;
		}else{
			counter += 1;
			PORTD ^= (1 << PD7);
			_delay_ms(flash_led);
			flash_led -= 9;
			score += 50;
			
			//preluarea datelor de la accelerometru
			mpu6050_getRawData(&ax, &ay, &az, &gx, &gy, &gz);
			
			lcd_goto_xy(y,x);
			lcd_chr(GOL);
			
			//variabile care tin pozitia anterioara a caracterului
			//pentru ca caracterul curent sa nu iasa de pe ecran
			//sau sa nu colizioneze cu un zid
			aux_y = y;
			aux_x = x;
			if(ay > 30) {
				y--;
			} else if(ay < -30) {
				y++;
			}
			switch(y)
			{
				case 0:
					y = aux_y;
					break;
				case 17:
					y = aux_y;
					break;
			}
			if(ax > 30) {
				x--;
			} else if(ax < -30) {
				x++;
			}
			switch(x)
			{
				case 0:
					x = aux_x;
					break;
				case 6:
					x = aux_x;
					break;
			}
			
			//coliziunile
			if(x == 1) {
				if(y == 6 || y == 7 || y == 10 || y == 11 || y == 17) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 2){
				if(y == 1 || y == 2 || y == 3 || y == 4 || y == 5 || y == 14 ||y == 17) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 3){
				if(y == 5 || y == 9 || y == 13 || y == 14 || y == 17) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 4){
				if(y == 1 || y == 2 || y == 3 || y == 4  || y == 5 || y == 6 || y == 9 || y == 10 || y == 14 || y == 17) {
					y = aux_y;
					x = aux_x;
				}
			}else if (x == 5){
				if(y == 14 || y == 17) {
					y = aux_y;
					x = aux_x;
				}
			}
			
			//daca am castigat se aduna in continuu scorul
			if((y == 15 && x == 5) || (y == 16 && x == 5)) {
				_delay_ms(200);
				
				bonus = 70 - counter;
				score += bonus * 8;
				DDRD |= (1 << PD4);
				PORTD &= ~(1 << PD7);
				
				lcd_clear();
				lcd_goto_xy(6,1);
				lcd_str("YOU WON!");
				sprintf(str, "%d", score);
				lcd_goto_xy(5,2);
				lcd_str("YOUR FINAL");
				lcd_goto_xy(5,3);
				lcd_str("SCORE IS: ");
				lcd_goto_xy(8,4);
				lcd_str(str);
				lcd_goto_xy(5, 5);
				lcd_str("ID PLAYER: ");
				lcd_goto_xy(8, 6);
				lcd_str(player);
				
				for(i = 0; i<700; ++i){
					update_song1();
					_delay_ms(25);
				}
				
				strcpy(str, "");
				lcd_clear();
				lcd_goto_xy(1,1);
				lcd_str("ID");
				lcd_goto_xy(9,1);
				lcd_str("SCORE");
				sprintf(str, "%d", score);
				strcat(scor_player, str);
				strcat(current_player, player);
				
				len = strlen(current_player);
				len1 = strlen(scor_player);
				
				DDRD &= ~(1 << PD4);
				col = 1;
				col1 = 9;
				for(i = 1; i < len; ++i){
					if(col == 6){
						col = 1;
						aux_xx+=1;
					}
						
					lcd_goto_xy(col,aux_xx);
					lcd_chr(current_player[i]);
						
					col+=1;
				}
				
				for(k = 1; k < len1; ++k){
					if(col1 == 13){
						col1 = 9;
						aux_xy+=1;
					}
					lcd_goto_xy(col1,aux_xy);
					lcd_chr(scor_player[k]);
						
					col1+=1;
				}
				
				_delay_ms(100000);
				
				DDRD |= (1 << PD4);
				
				lcd_clear();
				lcd_goto_xy(7,2);
				lcd_str("TO START ");
				lcd_goto_xy(4,3);
				lcd_str("A NEW GAME");
				lcd_goto_xy(6,4);
				lcd_str("PRESS #");
				strcpy(player, "");
				char k = button();
				if (k == '#'){
					DDRD &= ~(1 << PD4);
					while(1){
						id_player();
						_delay_ms(25);
						break;
					}
				}		
				
				break;
			}		
			lcd_goto_xy(y,x);
			lcd_chr(PLAYER);
			_delay_ms(200);
		}
	}
}

void level2(){
	int aux_xx = 2;
	int aux_xy = 2;
	int16_t ax, ay, az, gx, gy, gz;
	int flash_led = 200;
	counter = 0;
	int y = 1;
	int x = 2;
	int aux_x, aux_y;
	int i;
	int k;
	score = 0;
	
	lcd_clear();
	game_init2();
	
	while(1){
		if (counter == 70){
			_delay_ms(200);
			PORTD &= ~(1 << PD7);
			DDRD |= (1 << PD4);
			lcd_clear();
			lcd_goto_xy(6,1);
			lcd_str("YOU LOSE!");
			sprintf(str, "%d", score);
			lcd_goto_xy(5,2);
			lcd_str("YOUR FINAL");
			lcd_goto_xy(5,3);
			lcd_str("SCORE IS: ");
			lcd_goto_xy(7,4);
			lcd_str(str);
			lcd_goto_xy(5, 5);
			lcd_str("ID PLAYER: ");
			lcd_goto_xy(6, 6);
			lcd_str(player);
			
			for(i = 0; i<700; ++i){
				update_song2();
				_delay_ms(25);
			}
			
			strcpy(str, "");
			lcd_clear();
			lcd_goto_xy(1,1);
			lcd_str("ID");
			lcd_goto_xy(9,1);
			lcd_str("SCORE");
			sprintf(str, "%d", score);
			strcat(scor_player, str);
			strcat(current_player, player);
			
			len = strlen(current_player);
			len1 = strlen(scor_player);
			
			DDRD &= ~(1 << PD4);
			col = 1;
			col1 = 9;
			for(i = 1; i < len; ++i){
				if(col == 6){
					col = 1;
					aux_xx+=1;
				}
					
				lcd_goto_xy(col,aux_xx);
				lcd_chr(current_player[i]);
					
				col+=1;
			}
				
			for(k = 1; k < len1; ++k){
				if(col1 == 13){
					col1 = 9;
					aux_xy+=1;
				}
				lcd_goto_xy(col1,aux_xy);
				lcd_chr(scor_player[k]);
					
				col1+=1;
			}
			
			_delay_ms(100000);
			
			DDRD |= (1 << PD4);
			
			lcd_clear();
			lcd_goto_xy(7,2);
			lcd_str("TO START ");
			lcd_goto_xy(4,3);
			lcd_str("A NEW GAME");
			lcd_goto_xy(6,4);
			lcd_str("PRESS #");
			strcpy(player, "");
				
			char k = button();
			if (k == '#'){
				DDRD &= ~(1 << PD4);
				while(1){
					id_player();
					_delay_ms(25);
					break;
				}
			}		
			break;
		}else{
			counter += 1;
			PORTD ^= (1 << PD7);
			_delay_ms(flash_led);
			flash_led -= 20;
			score += 50;
			mpu6050_getRawData(&ax, &ay, &az, &gx, &gy, &gz);
			
			lcd_goto_xy(y,x);
			lcd_chr(GOL);

			aux_y = y;
			aux_x = x;
			if(ay > 30) {
				y--;
			} else if(ay < -30) {
				y++;
			}
			switch(y)
			{
				case 0:
					y = aux_y;
					break;
				case 17:
					y = aux_y;
					break;
			}
			if(ax > 30) {
				x--;
			} else if(ax < -30) {
				x++;
			}
			switch(x)
			{
				case 1:
					x = aux_x;
					break;
				case 6:
					x = aux_x;
					break;
			}

			if(x == 2) {
				if(y == 13 || y == 16) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 3){
				if(y == 1 || y == 2 || y == 3 || y == 6 || y == 7 || y == 8 || y == 9 || y == 13 || y == 16) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 4){
				if(y == 3 || y == 6 || y == 7 || y == 8 || y == 16) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 5){
				if(y == 3 || y == 11 || y == 12 || y == 13  || y == 14 || y == 15 || y == 16) {
					y = aux_y;
					x = aux_x;
				}
			}

			if((y == 15 && x == 2) || (y == 14 && x == 2)) {
				_delay_ms(200);
				PORTD &= ~(1 << PD7);
				bonus = 70 - counter;
				score += bonus * 4;	
				level3();
				break;
			}		
			lcd_goto_xy(y,x);
			lcd_chr(PLAYER);
			_delay_ms(200);
		}
	}
}

void level1(){
	int aux_xx = 2;
	int aux_xy = 2;
	counter = 0;
	int flash_led = 200;
	int16_t ax, ay, az, gx, gy, gz;
	int i=1;
	int k=1;
	int y = 1;
	int x = 2;
	int aux_x, aux_y;
	score = 0;
	
	lcd_clear();
	game_init();
	
	while(1){
		if(counter == 30){
			_delay_ms(200);
			PORTD &= ~(1 << PD7);
			DDRD |= (1 << PD4);
			lcd_clear();
			lcd_goto_xy(6,1);
			lcd_str("YOU LOSE!");
			sprintf(str, "%d", score);
			lcd_goto_xy(5,2);
			lcd_str("YOUR FINAL");
			lcd_goto_xy(5,3);
			lcd_str("SCORE IS: ");
			lcd_goto_xy(7,4);
			lcd_str(str);
			lcd_goto_xy(5, 5);
			lcd_str("ID PLAYER: ");
			lcd_goto_xy(6, 6);
			lcd_str(player);
			
			for(i = 0; i<700; ++i){
				update_song2();
				_delay_ms(25);
			}
			
			strcpy(str, "");
			lcd_clear();
			lcd_goto_xy(1,1);
			lcd_str("ID");
			lcd_goto_xy(9,1);
			lcd_str("SCORE");
			sprintf(str, "%d", score);
			strcat(scor_player, str);
			strcat(current_player, player);
			
			len = strlen(current_player);
			len1 = strlen(scor_player);
			
			DDRD &= ~(1 << PD4);
			col = 1;
			col1 = 9;
			for(i = 1; i < len; ++i){
				if(col == 6){
					col = 1;
					aux_xx+=1;
				}
					
				lcd_goto_xy(col,aux_xx);
				lcd_chr(current_player[i]);
					
				col+=1;
			}
				
			for(k = 1; k < len1; ++k){
				if(col1 == 13){
					col1 = 9;
					aux_xy+=1;
				}
				lcd_goto_xy(col1,aux_xy);
				lcd_chr(scor_player[k]);
					
				col1+=1;
			}
			
			_delay_ms(100000);
			
			DDRD |= (1 << PD4);
			
			lcd_clear();
			lcd_goto_xy(5,2);
			lcd_str("TO START ");
			lcd_goto_xy(4,3);
			lcd_str("A NEW GAME");
			lcd_goto_xy(6,4);
			lcd_str("PRESS #");
			strcpy(player, "");
				
			char k = button();
			if (k == '#'){
				DDRD &= ~(1 << PD4);
				while(1){
					id_player();
					_delay_ms(25);
					break;
				}
			}		
			break;
		}else{
			counter += 1;
			PORTD ^= (1 << PD7);
			_delay_ms(flash_led);
			score += 50;
			flash_led -= 20;
			
			mpu6050_getRawData(&ax, &ay, &az, &gx, &gy, &gz);
			
			lcd_goto_xy(y,x);
			lcd_chr(GOL);

			aux_y = y;
			aux_x = x;
			if(ay > 30) {
				y--;
			} else if(ay < -30) {
				y++;
			}
			switch(y)
			{
				case 0:
					y = aux_y;
					break;
				case 17:
					y = aux_y;
					break;
			}
			if(ax > 30) {
				x--;
			} else if(ax < -30) {
				x++;
			}
			switch(x)
			{
				case 1:
					x = aux_x;
					break;
				case 6:
					x = aux_x;
					break;
			}

			if(x == 2) {
				if(y == 10) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 3){
				if(y == 1 || y == 2 || y == 3 || y == 4  || y == 5 || y == 6 || y == 7 || y == 10) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 4){
				if(y == 7 || y == 10 || y == 11 || y == 12  || y == 13 || y == 14 || y == 15 || y == 16) {
					y = aux_y;
					x = aux_x;
				}
			} else if (x == 5){
				if(y == 7) {
					y = aux_y;
					x = aux_x;
				}
			}

			if(y == 16 && x == 5) {
				_delay_ms(200);
				PORTD &= ~(1 << PD7);
				bonus += 70 - counter;
				score += bonus * 2;
				level2();
				break;
			}		
			lcd_goto_xy(y,x);
			lcd_chr(PLAYER);
			_delay_ms(200);
		}
	}
}

//afisarea id-ului jucatorului curent
void id_player(){
	lcd_clear();
	lcd_goto_xy(5,2);
	lcd_str("ENTER YOUR");
	lcd_goto_xy(5,3);
	lcd_str("PLAYER ID: ");
	while(1){
		char key = button();
		if (key == '1'){
			strcat(player, "1");	
		}
		if (key == '2'){
			strcat(player, "2");
		}
		if (key == '3'){
			strcat(player, "3");
		}
		if (key == '4') {		
			strcat(player, "4");
		}
		if (key == '5') {
			strcat(player, "5");
		}
		if (key == '6'){
			strcat(player, "6");
		}
		if (key == '7') {
			strcat(player, "7");
		}
		if (key == '8'){
			strcat(player, "8");
		}
		if (key == '9'){
			strcat(player, "9");
		}
		if (key == 'A'){
			strcat(player, "A");
		}
		if (key == 'B'){
			strcat(player, "B");
		}
		if (key == 'C'){
			strcat(player, "C");
		}
		if (key == 'D'){
			strcat(player, "D");
		}
		if (key == '0'){
			strcat(player, "0");
		}
		if (key == '#'){
			while(1){
				level1();
				break;
			}
			break;
		}
		if (key == '*'){
			strcat(player, "*");
		}
		lcd_clear();
		lcd_goto_xy(5,2);
		lcd_str("ENTER YOUR");
		lcd_goto_xy(5,3);
		lcd_str("PLAYER ID: ");
		lcd_goto_xy(5,4);
		lcd_str(player);
	}
}

int main(){
	
	sei();
	
	//primii patru biti sunt folositi ca pini de intrare
	//ultimii patru biti sunt folositi ca pini de iesire
	DDRA = 0xF0;	
	//activez rezistentele de pull-up pentru primii patru biti
	PORTA = 0x0F;
	
	strcpy(player,"");
	strcpy(current_player,"");
	strcpy(current_player,"0");
	strcpy(scor_player,"");
	strcpy(scor_player,"0");
	strcpy(str,"");
	
	DDRD |= (1 << PD4);
	
	DDRD |= (1 << PD7);
	
	PORTD &= ~(1 << PD7);
	
	//initializez timer-ul, lcd-ul si accelerometrul
	lcd_init();
	mpu6050_init();
	timer1_init();
	
	lcd_clear();
	lcd_goto_xy(1,3);
	lcd_str("START GAME");
	lcd_goto_xy(1,4);
	lcd_str("PRESS # TO START");
	lcd_goto_xy(2,5);
	lcd_str("A NEW GAME");
	
    OCR1A = 0xFFFF;
	
	char key = button();
	
	if (key == '#'){
		DDRD &= ~(1 << PD4);
		while(1){
			id_player();
			_delay_ms(25);
			break;
		}
	}
    return 0;
}